@@ -38,6 +38,7 @@ ListPipelinesPaginatorName = Literal["list_pipelines"]
 ListPresetsPaginatorName = Literal["list_presets"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -70,6 +71,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
